#
# spec file for package bento4
#
# Copyright (c) 2023 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


%define _over   1.6.0-641
%define _libver 1_6_0r641
Name:           bento4
Version:        1.6.0r641
Release:        1699.1.pm.11
Summary:        C++ toolkit for all your MP4 and MPEG DASH media format needs
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            http://www.bento4.com/
Source0:        https://github.com/axiomatic-systems/Bento4/archive/v%{_over}.tar.gz#/%{name}-%{version}.tar.gz
Source99:       bento4-rpmlintrc
Patch0:         bento4-shared_library.patch
Patch1:         bento4-otherarchs.patch
BuildRequires:  cmake >= 3.10
BuildRequires:  gcc-c++

%description
Bento4 is a C++ class library and tools designed to read and write
ISO-MP4 files. This format is defined in international specifications
ISO/IEC 14496-12, 14496-14 and 14496-15. The format is a derivative of
the Apple Quicktime file format, so Bento4 can be used to read and
write most Quicktime files as well.

%package devel
Summary:        Headers and documentation to develop with libap4
Group:          Development/Libraries/C and C++
Requires:       libap4-%{_libver} = %{version}

%description devel
This package contains all necessary include files and documentation
needed to compile applications that use libap4.

%package -n libap4-%{_libver}
Summary:        C++ toolkit for all your MP4 and MPEG DASH media format needs
Group:          Productivity/Multimedia/Video/Players

%description -n libap4-%{_libver}
Bento4 is a C++ class library and tools designed to read and write
ISO-MP4 files. This format is defined in international specifications
ISO/IEC 14496-12, 14496-14 and 14496-15. The format is a derivative of
the Apple Quicktime file format, so Bento4 can be used to read and
write most Quicktime files as well.

%prep
%autosetup -p1 -n Bento4-%{_over}

%build
sed -e 's/__VERSION__/%{version}/g' -i CMakeLists.txt
%cmake
%cmake_build

%install
%cmake_install

%post -n libap4-%{_libver} -p /sbin/ldconfig
%postun -n libap4-%{_libver} -p /sbin/ldconfig

%files
%doc README.md
%{_bindir}/bento4-aac2mp4
%{_bindir}/bento4-avcinfo
%{_bindir}/bento4-fixaacsampledescription
%{_bindir}/bento4-hevcinfo
%{_bindir}/bento4-mp42aac
%{_bindir}/bento4-mp42avc
%{_bindir}/bento4-mp42hevc
%{_bindir}/bento4-mp42hls
%{_bindir}/bento4-mp42ts
%{_bindir}/bento4-mp4audioclip
%{_bindir}/bento4-mp4compact
%{_bindir}/bento4-mp4dcfpackager
%{_bindir}/bento4-mp4decrypt
%{_bindir}/bento4-mp4diff
%{_bindir}/bento4-mp4dump
%{_bindir}/bento4-mp4edit
%{_bindir}/bento4-mp4encrypt
%{_bindir}/bento4-mp4extract
%{_bindir}/bento4-mp4fragment
%{_bindir}/bento4-mp4iframeindex
%{_bindir}/bento4-mp4info
%{_bindir}/bento4-mp4mux
%{_bindir}/bento4-mp4pssh
%{_bindir}/bento4-mp4rtphintinfo
%{_bindir}/bento4-mp4split
%{_bindir}/bento4-mp4tag

%files devel
%doc README.md Documents/SDK/Bento4_SDK_documentation.pdf
%{_includedir}/bento4
%{_libdir}/cmake/bento4

%files -n libap4-%{_libver}
%license Documents/LICENSE.txt
%{_libdir}/libap4-%{version}.so

%changelog
* Sat Nov 25 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.6.0-641
- Refreshed bento4-shared_library.patch bento4-otherarchs.patch
  and bento4-rpmlintrc
* Sat May 20 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.6.0-640
* Sat Jul 24 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.6.0-639
* Sun Jun 13 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.6.0-638
* Wed Jun 24 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.6.0-637
* Sun Jun  7 2020 aloisio@gmx.com
- Update to version 1.6.0-636
- Refreshed bento4-shared_library.patch
* Mon May 18 2020 aloisio@gmx.com
- Update to version 1.6.0-634
- Refreshed bento4-otherarchs.patch
* Tue Nov 12 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.5.1-629
* Sun Jan 13 2019 aloisio@gmx.com
- Update to version 1.5.1-628
- Refreshed bento4-shared_library.patch
* Mon Jan  7 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.5.1-627
- Spec cleanup
* Mon May 28 2018 aloisio@gmx.com
- Update to version 1.5.1-624
* Sun Apr 22 2018 aloisio@gmx.com
- Update to 1.5.1-623
* Mon Jan  8 2018 aloisio@gmx.com
- Update to 1.5.1-622
* Mon Oct 16 2017 aloisio@gmx.com
- Update to 1.5.1-621
- Refreshed bento4-shared_library.patch
* Sat Oct  7 2017 aloisio@gmx.com
- Update to 1.5.1-620
* Sun Oct  1 2017 aloisio@gmx.com
- Update to 1.5.0-619
* Mon Sep 18 2017 aloisio@gmx.com
- Update to 1.5.0-618
* Thu Sep  7 2017 aloisio@gmx.com
- Update to 1.5.0-617
* Tue Sep  5 2017 aloisio@gmx.com
- Update to 1.5.0-616
- Refreshed bento4-otherarchs.patch
* Wed Jun  7 2017 aloisio@gmx.com
- Update to 1.5.0-615
* Tue Apr 11 2017 aloisio@gmx.com
- Initial package (v1.5.0-614)
